#include <stdio.h>
#include <string.h>
#include <sys/time.h>
#include <time.h>
#include <unistd.h>
#include <stdlib.h>

#include "pps-fixed.h"

enum display_mask {
	DISPLAY_CATEGORY    = 1 << 0,
	DISPLAY_SUBCATEGORY = 1 << 1,
	DISPLAY_FILMS       = 1 << 2,
	DISPLAY_FILES       = 1 << 3,
	DISPLAY_ALL         = 0xffff
};

static void dump_channel (ppscategory *cat, ppscategory *subcat, int mask)
{
	ppschannel* ch;
	ppsitem* item;

	ch = pps_vodlist_getchannel(cat->id, subcat ? subcat->id : 0,
				    subcat ? subcat->subcatnum : cat->subcatnum, 1);
	if (!ch)
		return;

	for (; ch; ch = ch->next)
	{
		printf ("\t\tfilm name: %s\n", ch->name);
		printf ("\t\tfilm director: %s\n", ch->director);
		printf ("\t\tactor: %s\n", ch->actor);
		printf ("\t\tarea: %s\n", ch->area);
		printf ("\t\tpubtime: %s\n", ch->pubtime);
		printf ("\t\tlang: %s\n", ch->lang);
		printf ("\t\tdesc: %s\n", ch->desc);

		if (mask & DISPLAY_FILES)
		{
			for (item = ch->pitems; item; item = item->next)
			{
				printf ("\t\t\turl: %s\n", item->ppsurl);
				printf ("\t\t\tvip_flag: %d\n", item->vipflag);
				printf ("\t\t\tformat: %s\n", item->format);
				printf ("\t\t\tsize: %dMB\n", item->size);
				printf ("\t\t\tduration: %dM\n", item->duration);
				printf ("\t\t\tbitrate: %d\n\n", item->bitrate);
			}
		}
	}
}

static void dump_category (ppscategory *cat, int mask)
{
	ppscategory *subcat;

	printf ("cat id: %d\n", cat->id);
	printf ("cat name: %s\n", cat->name);
	printf ("cat type: %d\n", cat->type);
	printf ("subcat num: %d\n", cat->subcatnum);

	if (cat->type == 0)
	{
		if (mask & DISPLAY_SUBCATEGORY)
		{
			for (subcat = cat->psubcat; subcat; subcat = subcat->next)
			{
				printf ("\tsubcat id: %d\n", subcat->id);
				printf ("\tsubcat name: %s\n", subcat->name);
				printf ("\tsubcat type: %d\n", subcat->type);
				printf ("\tsubcat num: %d\n", subcat->subcatnum);

				if (mask & DISPLAY_FILMS)
					dump_channel (cat, subcat, mask);

				printf ("\n");
			}
		}
	}
	else
	{
		if (mask & DISPLAY_FILMS)
			dump_channel (cat, NULL, mask);
	}
}

static void dump_vod_list(int mask)
{
	ppscategory *cat, *cur, *subcur;
	int catnum;

	cat = pps_vodlist_getcat(&catnum);
	if (!cat)
	{
		printf ("----Failed to get categories.\n");
		return;
	}

	if (mask & DISPLAY_CATEGORY)
	{
		for (cur = cat; cur; cur = cur->next)
			dump_category (cur, mask);
	}
}

int main(int argc, char** argv)
{
	int             ret = 0;
	int mask = DISPLAY_ALL;

	if (argc > 1)
		mask = atoi (argv[1]);

	printf ("--Intialize vod list--\n");
	ret = pps_vodlist_init();
	if (ret < 0)
	{
		printf ("--Failed to intialize vod list--\n");
		return -1;
	}

	dump_vod_list(mask);

	printf("------pps vod list uninitianlizing...\n");
	pps_vodlist_uninit();

	return 0;
}
